# Pseudo Columns

This module contains implementations for SQL pseudo-columns.

::: neopika.pseudocolumns
    handler: python
    options:
      members: true
      show_root_heading: false
      show_source: true
      heading_level: 2 